@@ -5,9 +5,8 @@ from absl import logging
 
 from tf_transformers.activations import get_activation
 from tf_transformers.core import LegacyLayer
-from tf_transformers.layers import (MLMLayer, OnDeviceEmbedding,
-                             SimplePositionEmbedding)
-from tf_transformers.layers.mask import CausalMask, SelfAttentionMask, prefix_mask, CrossAttentionMask
+from tf_transformers.layers import MLMLayer, OnDeviceEmbedding, SimplePositionEmbedding
+from tf_transformers.layers.mask import CausalMask, CrossAttentionMask, SelfAttentionMask, prefix_mask
 from tf_transformers.layers.transformer import TransformerBERT
 
 logging.set_verbosity("INFO")
@@ -47,6 +46,7 @@ class ROBERTAEncoder(LegacyLayer):
         encoder_positional_embedding_layer=None,
         use_mlm_layer=False,
         return_all_layer_token_embeddings=True,
+        attention_type="full_attention",
         **kwargs,
     ):
         """
@@ -77,7 +77,7 @@ class ROBERTAEncoder(LegacyLayer):
         self.type_vocab_size = config["type_vocab_size"]
         self.num_hidden_layers = config["num_hidden_layers"]
         self.num_attention_heads = config["num_attention_heads"]
-        self.attention_head_size = config['attention_head_size']
+        self.attention_head_size = config["attention_head_size"]
         self.max_position_embeddings = config["max_position_embeddings"]
         self.intermediate_size = config["intermediate_size"]
         self.embedding_size = config["embedding_size"]
@@ -112,6 +112,7 @@ class ROBERTAEncoder(LegacyLayer):
         self.use_mlm_layer = use_mlm_layer
         self.cross_attention_inside_encoder = cross_attention_inside_encoder
         self.return_all_layer_token_embeddings = return_all_layer_token_embeddings
+        self.attention_type = attention_type
 
         if not name.startswith("tf_transformers"):
             kwargs["name"] = "tf_transformers/" + self.model_name
@@ -133,7 +134,7 @@ class ROBERTAEncoder(LegacyLayer):
             "share_encoder_embeddings": self.share_encoder_embeddings,
             "share_attention_layers": self.share_attention_layers,
             "cross_attention_inside_encoder": cross_attention_inside_encoder,
-            "return_all_layer_token_embeddings": self.return_all_layer_token_embeddings
+            "return_all_layer_token_embeddings": self.return_all_layer_token_embeddings,
         }
 
         # Update config dict with passed config
@@ -148,7 +149,6 @@ class ROBERTAEncoder(LegacyLayer):
                 self._type_embeddings = encoder_type_embedding_layer
                 self._position_embedding_layer = encoder_positional_embedding_layer
 
-
         # Embedding Norm
         self._embedding_norm = tf.keras.layers.LayerNormalization(
             name="embeddings/layer_norm",
@@ -176,6 +176,7 @@ class ROBERTAEncoder(LegacyLayer):
                 share_attention_layers=share_attention_layers,
                 layer_norm_epsilon=self.layer_norm_epsilon,
                 cross_attention_inside_encoder=self.cross_attention_inside_encoder,
+                attention_type=self.attention_type,
                 name="transformer/layer_%d" % i,
             )
             self._transformer_layers.append(layer)
@@ -324,18 +325,6 @@ class ROBERTAEncoder(LegacyLayer):
             )
             encoder_outputs.append(embeddings)
 
-        def step_0_gather(past_length):
-            cache_length = tf.reduce_sum(tf.cast(tf.not_equal(input_ids_mod, -1), tf.int32), axis=1) - 1
-            # Getting corresponding last token tensor and last token logits
-            last_token_tensor = tf.gather_nd(embeddings, tf.expand_dims(cache_length, axis=1), batch_dims=1)
-            past_length = past_length + cache_length
-            return past_length, last_token_tensor
-
-        def step_other_gather(past_length):
-            past_length = past_length + sequence_length
-            last_token_tensor = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(encoder_outputs[-1])
-            return past_length, last_token_tensor
-
         # First word of last layer outputs [CLS]
         cls_token_tensor = tf.keras.layers.Lambda(lambda x: tf.squeeze(x[:, 0:1, :], axis=1))(encoder_outputs[-1])
         # batch_size x embedding_size
@@ -344,16 +333,6 @@ class ROBERTAEncoder(LegacyLayer):
         # batch_size x sequence_length x embedding_size
         token_embeddings = encoder_outputs[-1]
 
-        # Condition to switch functionsn (When batch_size > 1,
-        # past_length will be different for each entry)
-        # if `sum(past_length) = 0` , means no outputs has been generated.
-        # the given inputs is the first input
-        past_length, last_token_tensor = tf.cond(
-            tf.equal(tf.reduce_sum(past_length), 0),
-            lambda: step_0_gather(past_length),
-            lambda: step_other_gather(past_length),
-        )
-
         # MLM Projection
         if self.use_mlm_layer:
             token_embeddings = self.mlm_layer(token_embeddings)
@@ -376,7 +355,36 @@ class ROBERTAEncoder(LegacyLayer):
                 transpose_b=True,
                 name="token_logits",
             )
-        last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
+
+        def step_0_gather(past_length, token_embeddings):
+            cache_length = tf.reduce_sum(tf.cast(tf.not_equal(input_ids_mod, -1), tf.int32), axis=1) - 1
+            # Getting corresponding last token tensor and last token logits
+            last_token_tensor = tf.gather_nd(token_embeddings, tf.expand_dims(cache_length, axis=1), batch_dims=1)
+            past_length = past_length + cache_length
+            return past_length, last_token_tensor
+
+        def step_other_gather(past_length, token_embeddings):
+            past_length = past_length + sequence_length
+            last_token_tensor = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_embeddings)
+            return past_length, last_token_tensor
+
+        # Condition to switch functionsn (When batch_size > 1,
+        # past_length will be different for each entry)
+        # if `sum(past_length) = 0` , means no outputs has been generated.
+        # the given inputs is the first input
+        past_length, last_token_tensor = tf.cond(
+            tf.equal(tf.reduce_sum(past_length), 0),
+            lambda: step_0_gather(past_length, token_embeddings),
+            lambda: step_other_gather(past_length, token_embeddings),
+        )
+
+        # token --> vocab ( batch_size x sequence_length x vocab_size)
+        last_token_logits = tf.matmul(
+            last_token_tensor,
+            self.get_embedding_table(),
+            transpose_b=True,
+            name="token_logits",
+        )
 
         # Expand dims of past_length back to 2D
         past_length = tf.expand_dims(past_length, 0, name="past_length")
@@ -388,6 +396,7 @@ class ROBERTAEncoder(LegacyLayer):
         return {
             "cls_output": cls_output,
             "token_logits": token_logits,
+            "token_embeddings": token_embeddings,
             "last_token_logits": last_token_logits,
             "past_length": past_length,
             "all_cache_key": all_cache_key,
@@ -426,14 +435,17 @@ class ROBERTAEncoder(LegacyLayer):
         embeddings = self._embedding_norm(embeddings)
         embeddings = self._embedding_dropout(embeddings, training=self.use_dropout)
 
-        # Initialize `attention_mask` as empty list
-        attention_mask = []
-        if self.mask_mode == "user_defined":
-            attention_mask = SelfAttentionMask()([embeddings, input_mask])
-        if self.mask_mode == "prefix":
-            attention_mask = tf.map_fn(prefix_mask, input_mask, dtype=tf.float32)
-        if self.mask_mode == "causal":
-            attention_mask = CausalMask()(embeddings)
+        if self.attention_type == "block_attention" or self.attention_type == "bigbird":
+            attention_mask = input_mask
+        else:
+            # Initialize `attention_mask` as empty list
+            attention_mask = []
+            if self.mask_mode == "user_defined":
+                attention_mask = SelfAttentionMask()([embeddings, input_mask])
+            if self.mask_mode == "prefix":
+                attention_mask = tf.map_fn(prefix_mask, input_mask, dtype=tf.float32)
+            if self.mask_mode == "causal":
+                attention_mask = CausalMask()(embeddings)
 
         encoder_outputs = []
         for i in range(self.num_hidden_layers):
@@ -448,6 +460,13 @@ class ROBERTAEncoder(LegacyLayer):
         # batch_size x sequence_length x embedding_size
         token_embeddings = encoder_outputs[-1]
 
+        all_cls_output = []
+        for per_layer_token_embeddings in encoder_outputs:
+            per_cls_token_tensor = tf.keras.layers.Lambda(lambda x: tf.squeeze(x[:, 0:1, :], axis=1))(
+                per_layer_token_embeddings
+            )
+            all_cls_output.append(self._pooler_layer(per_cls_token_tensor))
+
         # MLM Projection
         if self.use_mlm_layer:
             token_embeddings = self.mlm_layer(token_embeddings)
@@ -481,7 +500,8 @@ class ROBERTAEncoder(LegacyLayer):
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = encoder_outputs
+            result["all_layer_token_embeddings"] = encoder_outputs
+            result["all_layer_cls_output"] = all_cls_output
         return result
 
     def call_cross_attention_encoder(self, inputs):
@@ -549,10 +569,10 @@ class ROBERTAEncoder(LegacyLayer):
                 [
                     encoder_embeddings,
                     encoder_attention_mask,
-                    decoder_encoder_mask, # dummy decoder_encoder_mask
-                    encoder_embeddings, # dummy encoder_hidden_states
+                    decoder_encoder_mask,  # dummy decoder_encoder_mask
+                    encoder_embeddings,  # dummy encoder_hidden_states
                 ],
-                mode = 'encoder'
+                mode="encoder",
             )
             encoder_outputs.append(encoder_embeddings)
 
@@ -561,13 +581,8 @@ class ROBERTAEncoder(LegacyLayer):
         for i in range(self.num_hidden_layers):
             layer = self._transformer_layers[i]
             decoder_embeddings, _, _ = layer(
-                [
-                    decoder_embeddings,
-                    decoder_attention_mask,
-                    decoder_encoder_mask,
-                    encoder_hidden_states
-                ],
-                mode = 'decoder'
+                [decoder_embeddings, decoder_attention_mask, decoder_encoder_mask, encoder_hidden_states],
+                mode="decoder",
             )
             decoder_outputs.append(decoder_embeddings)
         # First word of last layer outputs [CLS]
@@ -610,10 +625,9 @@ class ROBERTAEncoder(LegacyLayer):
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_outputs
+            result["all_layer_token_embeddings"] = decoder_outputs
         return result
 
-
     def call_cross_attention_encoder_predict(self, inputs):
         """[summary]
 
@@ -671,6 +685,7 @@ class ROBERTAEncoder(LegacyLayer):
                 input_ids ([type]): [description]
                 input_type_ids ([type]): [description]
             """
+
             def step_0_cache_length(_):
                 return tf.constant(0, dtype=tf.int32)
 
@@ -731,7 +746,7 @@ class ROBERTAEncoder(LegacyLayer):
 
         # Decoder mask is always None
         decoder_attention_mask = CausalMask()(decoder_embeddings)
-        decoder_encoder_mask   = CrossAttentionMask()([decoder_input_ids, encoder_input_mask])
+        decoder_encoder_mask = CrossAttentionMask()([decoder_input_ids, encoder_input_mask])
 
         all_cache_key = [
             tf.squeeze(item, axis=0)
@@ -753,12 +768,12 @@ class ROBERTAEncoder(LegacyLayer):
                     [
                         encoder_embeddings,
                         encoder_attention_mask,
-                        decoder_encoder_mask, # decoder_encoder_mask
+                        decoder_encoder_mask,  # decoder_encoder_mask
                         encoder_embeddings,
                     ],
-                    mode = 'encoder',
-                cache_key=cache_key,
-                cache_value=cache_value,
+                    mode="encoder",
+                    cache_key=cache_key,
+                    cache_value=cache_value,
                 )
                 encoder_outputs.append(encoder_embeddings)
             encoder_hidden_states = encoder_outputs[-1]
@@ -787,7 +802,7 @@ class ROBERTAEncoder(LegacyLayer):
                     decoder_encoder_mask,
                     encoder_hidden_states,
                 ],
-                mode = 'decoder',
+                mode="decoder",
                 cache_key=cache_key,
                 cache_value=cache_value,
             )
@@ -842,7 +857,6 @@ class ROBERTAEncoder(LegacyLayer):
             "last_token_logits": last_token_logits,
         }
 
-
     def call_decoder_predict(self, inputs):
         """Inputs will be pass to this method, when is_training = False and is_decoder = True. # noqa
         The need to cache the past `key` and `value`
@@ -1066,10 +1080,9 @@ class ROBERTAEncoder(LegacyLayer):
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_outputs
+            result["all_layer_token_embeddings"] = decoder_outputs
         return result
 
-
     def call(self, inputs):
         """Forward Pass.
         We have 2 pipelines . Training pipeline is relatively simpler
