@@ -5,12 +5,10 @@ from absl import logging
 
 from tf_transformers.activations import get_activation
 from tf_transformers.core import LegacyLayer
-from tf_transformers.layers import (
-    OnDeviceEmbedding,
-    SimplePositionEmbedding,
-    T5LayerNormalization,
-)
-from tf_transformers.layers.mask import CausalMask, SelfAttentionMask, prefix_mask
+from tf_transformers.layers import (OnDeviceEmbedding, SimplePositionEmbedding,
+                                    T5LayerNormalization)
+from tf_transformers.layers.mask import (CausalMask, SelfAttentionMask,
+                                         prefix_mask)
 from tf_transformers.layers.transformer import TransformerT5
 
 logging.set_verbosity("INFO")
@@ -49,7 +47,7 @@ class T5Encoder(LegacyLayer):
         encoder_positional_embedding_layer=None,
         cross_attention_inside_encoder=False,
         return_all_layer_token_embeddings=True,
-        **kwargs
+        **kwargs,
     ):
         """
         Args:
@@ -93,9 +91,7 @@ class T5Encoder(LegacyLayer):
         # Get activation and initiliazers
         self.activation = get_activation(self.hidden_act)
         self.intermediate_activation = get_activation(self.intermediate_act)
-        initializer = tf.keras.initializers.TruncatedNormal(
-            stddev=self.initializer_range
-        )
+        initializer = tf.keras.initializers.TruncatedNormal(stddev=self.initializer_range)
         self.initializer = tf.keras.initializers.get(initializer)
         self.mask_mode = mask_mode
         # If we use self.name , its a conflict with keras property
@@ -136,7 +132,7 @@ class T5Encoder(LegacyLayer):
             "share_encoder_embeddings": self.share_encoder_embeddings,
             "share_attention_layers": self.share_attention_layers,
             "cross_attention_inside_encoder": cross_attention_inside_encoder,
-            "return_all_layer_token_embeddings": self.return_all_layer_token_embeddings
+            "return_all_layer_token_embeddings": self.return_all_layer_token_embeddings,
         }
 
         # Update config dict with passed config
@@ -185,14 +181,10 @@ class T5Encoder(LegacyLayer):
             )
             self._transformer_layers.append(layer)
 
-        self._last_layer_norm = T5LayerNormalization(
-            name="last_layer_norm", axis=-1, epsilon=1e-6, dtype=tf.float32
-        )
-        self._last_layer_dropout = tf.keras.layers.Dropout(
-            rate=self.hidden_dropout_prob
-        )
+        self._last_layer_norm = T5LayerNormalization(name="last_layer_norm", axis=-1, epsilon=1e-6, dtype=tf.float32)
+        self._last_layer_dropout = tf.keras.layers.Dropout(rate=self.hidden_dropout_prob)
         self.call_fn = self.get_call_method()
-        #### Initialize model
+        # Initialize model
         self.model_inputs, self.model_ouputs = self.get_model(initialize_only=True)
         logging.info("Initialized Variables")
 
@@ -222,9 +214,7 @@ class T5Encoder(LegacyLayer):
             type_embeddings = self._type_embeddings(input_type_ids)
             embeddings = embeddings + type_embeddings
         if self.use_positonal_embeddings:
-            positional_embeddings = self._position_embedding_layer(
-                tf.range(sequence_length)
-            )
+            positional_embeddings = self._position_embedding_layer(tf.range(sequence_length))
             embeddings = embeddings + positional_embeddings
 
         # Norm + dropout
@@ -235,9 +225,7 @@ class T5Encoder(LegacyLayer):
         if self.mask_mode == "user_defined":
             attention_mask = SelfAttentionMask()([embeddings, input_mask])
         if self.mask_mode == "prefix":
-            attention_mask = tf.map_fn(
-                prefix_mask, input_mask, fn_output_signature=tf.float32
-            )
+            attention_mask = tf.map_fn(prefix_mask, input_mask, fn_output_signature=tf.float32)
         if self.mask_mode == "causal":
             attention_mask = CausalMask()(embeddings)
 
@@ -245,9 +233,7 @@ class T5Encoder(LegacyLayer):
         position_bias = None
         for i in range(self.num_hidden_layers):
             layer = self._transformer_layers[i]
-            embeddings, position_bias, k, v = layer(
-                [embeddings, attention_mask], position_bias=position_bias
-            )
+            embeddings, position_bias, k, v = layer([embeddings, attention_mask], position_bias=position_bias)
             encoder_outputs.append(embeddings)
 
         encoder_outputs[-1] = self._last_layer_norm(encoder_outputs[-1])
@@ -270,7 +256,7 @@ class T5Encoder(LegacyLayer):
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = encoder_outputs
+            result["all_layer_token_embeddings"] = encoder_outputs
         return result
 
     def call_predict(self, inputs):
@@ -309,15 +295,11 @@ class T5Encoder(LegacyLayer):
 
         all_cache_key = [
             tf.squeeze(item, axis=0)
-            for item in tf.split(
-                all_cache_key, num_or_size_splits=self.num_hidden_layers, axis=0
-            )
+            for item in tf.split(all_cache_key, num_or_size_splits=self.num_hidden_layers, axis=0)
         ]
         all_cache_value = [
             tf.squeeze(item, axis=0)
-            for item in tf.split(
-                all_cache_value, num_or_size_splits=self.num_hidden_layers, axis=0
-            )
+            for item in tf.split(all_cache_value, num_or_size_splits=self.num_hidden_layers, axis=0)
         ]
 
         # If decoder is not sharing embeddings
@@ -348,13 +330,7 @@ class T5Encoder(LegacyLayer):
             cache_value = all_cache_value[i]
             cache_key = all_cache_key[i]
 
-            (
-                embeddings,
-                position_bias,
-                decoder_encoder_position_bias,
-                cache_key,
-                cache_value,
-            ) = layer(
+            (embeddings, position_bias, decoder_encoder_position_bias, cache_key, cache_value,) = layer(
                 [
                     embeddings,
                     attention_mask,
@@ -467,14 +443,14 @@ class T5Encoder(LegacyLayer):
         )
         last_token_logits = tf.keras.layers.Lambda(lambda x: x[:, -1, :])(token_logits)
 
-        return {
+        result = {
             "token_embeddings": token_embeddings,
             "token_logits": token_logits,
             "last_token_logits": last_token_logits,
         }
 
         if self.return_all_layer_token_embeddings:
-            result['all_layer_token_embeddings'] = decoder_outputs
+            result["all_layer_token_embeddings"] = decoder_outputs
         return result
 
     def call(self, inputs):
