@@ -3,7 +3,8 @@ import tensorflow as tf
 import tensorflow_hub as hub
 
 from tf_transformers.text import (_gather_beams, _log_prob_from_logits,
-                           assign_zeros_to_K_V, top_k_logits, top_p_logits)
+                                  assign_zeros_to_K_V, top_k_logits,
+                                  top_p_logits)
 
 
 class TextDecoder(object):
@@ -25,11 +26,18 @@ class TextDecoder(object):
         """
         self.model = model
         self.model_fn = None
+        self.input_type_ids = input_type_ids
+        self.input_mask_ids = input_mask_ids
         # keras Model
         if isinstance(model, tf.keras.Model):
             self.model_fn = self.model
             model_config = model.model_config
-            self.embedding_size, self.num_attention_heads,self.num_hidden_layers, self.attention_state = self.auto_infer_config(model_config, saved_model=False)
+            (
+                self.embedding_size,
+                self.num_attention_heads,
+                self.num_hidden_layers,
+                self.attention_state,
+            ) = self.auto_infer_config(model_config, saved_model=False)
 
             # Validate decoder type ids are there
             self.validate_decoder_type_ids(model.input)
@@ -41,28 +49,41 @@ class TextDecoder(object):
             # saved model
             if "saved_model" in str(type(self.model)):
                 # Extract signature
-                self.model_pb = self.model.signatures['serving_default']
+                self.model_pb = self.model.signatures["serving_default"]
+
                 def model_fn(x):
                     return self.model_pb(**x)
 
                 self.model_fn = model_fn
 
             model_config = self.model.config
-            self.embedding_size, self.num_attention_heads,self.num_hidden_layers, self.attention_state = self.auto_infer_config(model_config, saved_model=True)
+            (
+                self.embedding_size,
+                self.num_attention_heads,
+                self.num_hidden_layers,
+                self.attention_state,
+            ) = self.auto_infer_config(model_config, saved_model=True)
 
             # Validate decoder type ids are there
             self.validate_decoder_type_ids(self.model_pb.structured_input_signature[1])
 
         if self.model_fn is None:
             raise ValueError("Please check the type of your model")
-        self.input_type_ids = input_type_ids
-        self.input_mask_ids = input_mask_ids
         self.reserved_input_keys = ["input_ids", "input_mask", "input_type_ids"]
 
-    def validate_decoder_type_ids(self,inputs):
+    def validate_decoder_type_ids(self, inputs):
         if "input_type_ids" in inputs:
             if self.input_type_ids < 0:
-                raise ValueError("Seems like you model has `decoder_input_type_ids`, but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`")
+                raise ValueError(
+                    "Seems like you model has `input_type_ids`, \
+                        but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`"
+                )
+        if "input_mask" in inputs:
+            if self.input_mask_ids < 0:
+                raise ValueError(
+                    "Seems like you model has `input_mask_ids`, \
+                        but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`"
+                )
 
     def auto_infer_config(self, config, saved_model=False):
         """[summary]
@@ -74,16 +95,16 @@ class TextDecoder(object):
             [type]: [description]
         """
         if saved_model:
-            embedding_size = config['embedding_size'].numpy()
-            num_attention_heads = config['num_attention_heads'].numpy()
-            num_hidden_layers = config['num_hidden_layers'].numpy()
-            attention_head_size = config['attention_head_size'].numpy()
+            embedding_size = config["embedding_size"].numpy()
+            num_attention_heads = config["num_attention_heads"].numpy()
+            num_hidden_layers = config["num_hidden_layers"].numpy()
+            attention_head_size = config["attention_head_size"].numpy()
             return (embedding_size, num_attention_heads, num_hidden_layers, attention_head_size)
         else:
-            embedding_size = config['embedding_size']
-            num_attention_heads = config['num_attention_heads']
-            num_hidden_layers = config['num_hidden_layers']
-            attention_head_size = config['attention_head_size']
+            embedding_size = config["embedding_size"]
+            num_attention_heads = config["num_attention_heads"]
+            num_hidden_layers = config["num_hidden_layers"]
+            attention_head_size = config["attention_head_size"]
             return (embedding_size, num_attention_heads, num_hidden_layers, attention_head_size)
 
     def reorder_past_batches(self, all_cache_key, all_cache_value, coordinates, beam_size):
@@ -100,12 +121,9 @@ class TextDecoder(object):
         return all_cache_key, all_cache_value
 
     # Greedy Decoding
-    def greedy_decode(self,
-        tokenized_input_dict_original,
-        max_iterations,
-        do_sample=False,
-        temperature=1.0,
-        eos_id=-100):
+    def greedy_decode(
+        self, tokenized_input_dict_original, max_iterations, do_sample=False, temperature=1.0, eos_id=-100
+    ):
         """
         Greedy Decoding
 
@@ -140,10 +158,8 @@ class TextDecoder(object):
         tokenized_input_dict["all_cache_value"] = all_cache_value
         tokenized_input_dict["past_length"] = past_length
 
-        if self.input_type_ids > -1:
-            tokenized_input_dict["input_type_ids"] = tf.ones_like(tokenized_input_dict["input_ids"]) * self.input_type_ids
-
         all_predictions = []
+        all_prediction_probs = []
         matched_positions = tf.constant([-1] * batch_size)
         # Iterate
         for i in range(max_iterations):
@@ -159,7 +175,9 @@ class TextDecoder(object):
                 input_ids = tf.cast(prediction_ids, tf.int32)
             else:
                 prediction_ids = tf.argmax(model_logits, axis=1)
+                prediction_probs = tf.reduce_max(model_logits, axis=1)
                 input_ids = tf.expand_dims(prediction_ids, axis=1)
+                all_prediction_probs.append(prediction_probs)
 
             all_predictions.append(input_ids)
 
@@ -195,6 +213,15 @@ class TextDecoder(object):
             tokenized_input_dict["all_cache_value"] = all_cache_value
             tokenized_input_dict["past_length"] = past_length
 
+            if self.input_type_ids > -1:
+                tokenized_input_dict["input_type_ids"] = (
+                    tf.ones_like(tokenized_input_dict["input_ids"]) * self.input_type_ids
+                )
+            if self.input_mask_ids > -1:
+                tokenized_input_dict["input_mask"] = (
+                    tf.ones_like(tokenized_input_dict["input_ids"]) * self.input_mask_ids
+                )
+
         all_predictions = tf.concat(all_predictions, axis=1)
         matched_positions = tf.reshape(tf.argmax(tf.cast(tf.equal(eos_id, all_predictions), tf.int32), axis=1), -1)
         # no eos matched positions will be 0, replace with -1
@@ -207,6 +234,7 @@ class TextDecoder(object):
             "input_ids": input_ids_original,
             "predicted_ids": all_predictions,
             "matched_eos_pos": matched_positions,
+            "prediction_probs": all_prediction_probs,
         }
 
     def beam_decode(
@@ -270,7 +298,13 @@ class TextDecoder(object):
         tokenized_input_dict_ragged["past_length"] = past_length
 
         if self.input_type_ids > -1:
-            tokenized_input_dict_ragged["input_type_ids"] = tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_type_ids
+            tokenized_input_dict_ragged["input_type_ids"] = (
+                tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_type_ids
+            )
+        if self.input_mask_ids > -1:
+            tokenized_input_dict_ragged["input_mask"] = (
+                tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_mask_ids
+            )
 
         alive_log_probs = -np.inf * tf.ones((batch_size, beam_size - 1))
 
@@ -309,7 +343,7 @@ class TextDecoder(object):
             log_probs = candidate_log_probs + tf.expand_dims(alive_log_probs, axis=2)
 
             # Add length penalty
-            length_penalty = tf.pow(((5. + (tf.cast(i, tf.float32) + 1.0)) / 6.), alpha)
+            length_penalty = tf.pow(((5.0 + (tf.cast(i, tf.float32) + 1.0)) / 6.0), alpha)
             log_probs = log_probs / length_penalty
 
             # Each batch item has beam_size * vocab_size candidate sequences. For each
@@ -333,7 +367,7 @@ class TextDecoder(object):
                 topk_log_probs = next_scores
                 topk_indices = next_tokens
             else:
-                topk_log_probs, topk_indices = tf.nn.top_k(flat_log_probs, k=beams_to_keep) # (batch_size x k)
+                topk_log_probs, topk_indices = tf.nn.top_k(flat_log_probs, k=beams_to_keep)  # (batch_size x k)
 
             topk_beam_indices = topk_indices // vocab_size
             topk_seq, coordinates = _gather_beams(alive_seq, topk_beam_indices, batch_size, beams_to_keep)
@@ -371,6 +405,15 @@ class TextDecoder(object):
             tokenized_input_dict_ragged["all_cache_value"] = all_cache_value
             tokenized_input_dict_ragged["past_length"] = past_length
 
+            if self.input_type_ids > -1:
+                tokenized_input_dict_ragged["input_type_ids"] = (
+                    tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_type_ids
+                )
+            if self.input_mask_ids > -1:
+                tokenized_input_dict_ragged["input_mask"] = (
+                    tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_mask_ids
+                )
+
             if eos_id:
                 eos_check = tf.greater(
                     tf.reduce_prod(
@@ -457,7 +500,13 @@ class TextDecoder(object):
         tokenized_input_dict_ragged["past_length"] = past_length
 
         if self.input_type_ids > -1:
-            tokenized_input_dict_ragged["input_type_ids"] = tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_type_ids
+            tokenized_input_dict_ragged["input_type_ids"] = (
+                tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_type_ids
+            )
+        if self.input_mask_ids > -1:
+            tokenized_input_dict_ragged["input_mask"] = (
+                tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_mask_ids
+            )
 
         all_predictions = []
         matched_positions = tf.constant([-1] * batch_size_updated)
@@ -501,6 +550,15 @@ class TextDecoder(object):
             tokenized_input_dict_ragged["all_cache_value"] = all_cache_value
             tokenized_input_dict_ragged["past_length"] = past_length
 
+            if self.input_type_ids > -1:
+                tokenized_input_dict_ragged["input_type_ids"] = (
+                    tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_type_ids
+                )
+            if self.input_mask_ids > -1:
+                tokenized_input_dict_ragged["input_mask"] = (
+                    tf.ones_like(tokenized_input_dict_ragged["input_ids"]) * self.input_mask_ids
+                )
+
             if eos_id:
                 temp_m = tf.concat(all_predictions, axis=1)
                 eos_check = tf.greater(
@@ -541,7 +599,7 @@ class TextDecoder(object):
         beam_size=3,
         num_return_sequences=1,
         sampling_temperature=1.0,
-        alpha = 0.0,
+        alpha=0.0,
         eos_id=-100,
         top_k=0,
         top_p=0,
@@ -549,7 +607,13 @@ class TextDecoder(object):
         mode="greedy",
     ):
         if mode == "greedy":
-            result = self.greedy_decode(tokenized_input_dict, max_iterations=max_iterations, temperature=sampling_temperature, do_sample=do_sample, eos_id=eos_id)
+            result = self.greedy_decode(
+                tokenized_input_dict,
+                max_iterations=max_iterations,
+                temperature=sampling_temperature,
+                do_sample=do_sample,
+                eos_id=eos_id,
+            )
         if mode == "beam":
             result = self.beam_decode(
                 tokenized_input_dict,
