@@ -3,7 +3,8 @@ import tensorflow as tf
 import tensorflow_hub as hub
 
 from tf_transformers.text import (_gather_beams, _log_prob_from_logits,
-                           assign_zeros_to_K_V, top_k_logits, top_p_logits)
+                                  assign_zeros_to_K_V, top_k_logits,
+                                  top_p_logits)
 
 
 class TextDecoderSeq2Seq(object):
@@ -38,7 +39,7 @@ class TextDecoderSeq2Seq(object):
         Returns:
             [type]: [description]
         """
-        self.decode_start_token_id  = decoder_start_token_id
+        self.decode_start_token_id = decoder_start_token_id
         self.decoder_input_type_ids = decoder_input_type_ids
         self.decoder_input_mask_ids = decoder_input_mask_ids
 
@@ -47,8 +48,13 @@ class TextDecoderSeq2Seq(object):
         # keras Model
         if isinstance(model, tf.keras.Model):
             self.model_fn = self.model
-            decoder_config = model.model_config['decoder']
-            self.embedding_size, self.decoder_num_attention_heads,self.decoder_num_hidden_layers, self.decoder_attention_state  = self.auto_infer_config(decoder_config, saved_model=False)
+            decoder_config = model.model_config["decoder"]
+            (
+                self.embedding_size,
+                self.decoder_num_attention_heads,
+                self.decoder_num_hidden_layers,
+                self.decoder_attention_state,
+            ) = self.auto_infer_config(decoder_config, saved_model=False)
 
             # Validate decoder type ids are there
             self.validate_decoder_type_ids(model.input)
@@ -60,14 +66,20 @@ class TextDecoderSeq2Seq(object):
             # saved model
             if "saved_model" in str(type(self.model)):
                 # Extract signature
-                self.model_pb = self.model.signatures['serving_default']
+                self.model_pb = self.model.signatures["serving_default"]
+
                 def model_fn(x):
                     return self.model_pb(**x)
 
                 self.model_fn = model_fn
 
             decoder_config = self.model.config
-            self.embedding_size, self.decoder_num_attention_heads,self.decoder_num_hidden_layers, self.decoder_attention_state  = self.auto_infer_config(decoder_config, saved_model=True)
+            (
+                self.embedding_size,
+                self.decoder_num_attention_heads,
+                self.decoder_num_hidden_layers,
+                self.decoder_attention_state,
+            ) = self.auto_infer_config(decoder_config, saved_model=True)
 
             # Validate decoder type ids are there
             self.validate_decoder_type_ids(self.model_pb.structured_input_signature[1])
@@ -76,10 +88,13 @@ class TextDecoderSeq2Seq(object):
             raise ValueError("Please check the type of your model")
         self.reserved_input_keys = ["input_ids", "input_mask", "input_type_ids"]
 
-    def validate_decoder_type_ids(self,inputs):
+    def validate_decoder_type_ids(self, inputs):
         if "decoder_input_type_ids" in inputs:
             if self.decoder_input_type_ids < 0:
-                raise ValueError("Seems like you model has `decoder_input_type_ids`, but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`")
+                raise ValueError(
+                    "Seems like you model has `decoder_input_type_ids`, \
+                        but it hasn't set yet. Please provide a valid positive index for `decoder_input_type_ids`"
+                )
 
     def auto_infer_config(self, config, saved_model=False):
         """[summary]
@@ -91,16 +106,16 @@ class TextDecoderSeq2Seq(object):
             [type]: [description]
         """
         if saved_model:
-            embedding_size = config['embedding_size'].numpy()
-            decoder_num_attention_heads = config['num_attention_heads'].numpy()
-            decoder_num_hidden_layers = config['num_hidden_layers'].numpy()
-            attention_head_size = config['attention_head_size'].numpy()
+            embedding_size = config["embedding_size"].numpy()
+            decoder_num_attention_heads = config["num_attention_heads"].numpy()
+            decoder_num_hidden_layers = config["num_hidden_layers"].numpy()
+            attention_head_size = config["attention_head_size"].numpy()
             return (embedding_size, decoder_num_attention_heads, decoder_num_hidden_layers, attention_head_size)
         else:
-            embedding_size = config['embedding_size']
-            decoder_num_attention_heads = config['num_attention_heads']
-            decoder_num_hidden_layers = config['num_hidden_layers']
-            attention_head_size = config['attention_head_size']
+            embedding_size = config["embedding_size"]
+            decoder_num_attention_heads = config["num_attention_heads"]
+            decoder_num_hidden_layers = config["num_hidden_layers"]
+            attention_head_size = config["attention_head_size"]
             return (embedding_size, decoder_num_attention_heads, decoder_num_hidden_layers, attention_head_size)
 
     def reorder_past_batches(self, all_cache_key, all_cache_value, coordinates, beam_size):
@@ -131,12 +146,9 @@ class TextDecoderSeq2Seq(object):
         return all_cache_key, all_cache_value
 
     # Greedy Decoding
-    def greedy_decode(self,
-        tokenized_input_dict_original,
-        max_iterations,
-        do_sample=False,
-        temperature=1.0,
-        eos_id=-100):
+    def greedy_decode(
+        self, tokenized_input_dict_original, max_iterations, do_sample=False, temperature=1.0, eos_id=-100
+    ):
         """
         Greedy Decoding
 
@@ -177,9 +189,10 @@ class TextDecoderSeq2Seq(object):
             tf.ones(shape=(batch_size, 1)) * self.decode_start_token_id, tf.int32
         )
 
-
         if self.decoder_input_type_ids > -1:
-            tokenized_input_dict["decoder_input_type_ids"] = tf.ones_like(tokenized_input_dict["decoder_input_ids"]) * self.decoder_input_type_ids
+            tokenized_input_dict["decoder_input_type_ids"] = (
+                tf.ones_like(tokenized_input_dict["decoder_input_ids"]) * self.decoder_input_type_ids
+            )
 
         tokenized_input_dict["decoder_all_cache_key"] = all_cache_key
         tokenized_input_dict["decoder_all_cache_value"] = all_cache_value
@@ -204,8 +217,7 @@ class TextDecoderSeq2Seq(object):
                 input_ids = tf.expand_dims(prediction_ids, axis=1)
 
             all_predictions.append(input_ids)
-
-            temp_m = tf.concat(all_predictions, axis=1)
+            # temp_m = tf.concat(all_predictions, axis=1)
             eos_check = tf.greater(
                 tf.reduce_prod(
                     tf.reduce_sum(
@@ -319,7 +331,9 @@ class TextDecoderSeq2Seq(object):
         tokenized_input_dict_ragged["encoder_hidden_states"] = encoder_hidden_states
 
         if self.decoder_input_type_ids > -1:
-            tokenized_input_dict_ragged["decoder_input_type_ids"] = tf.ones_like(tokenized_input_dict_ragged["decoder_input_ids"]) * self.decoder_input_type_ids
+            tokenized_input_dict_ragged["decoder_input_type_ids"] = (
+                tf.ones_like(tokenized_input_dict_ragged["decoder_input_ids"]) * self.decoder_input_type_ids
+            )
 
         matched_positions = tf.constant([-1] * batch_size_updated)
 
@@ -339,7 +353,7 @@ class TextDecoderSeq2Seq(object):
             all_cache_value = result["decoder_all_cache_value"]
             encoder_hidden_states = result["encoder_hidden_states"]
 
-            model_logits = model_logits/temperature
+            model_logits = model_logits / temperature
 
             if top_k > 0:
                 model_logits = top_k_logits(model_logits, k=top_k)
@@ -362,7 +376,7 @@ class TextDecoderSeq2Seq(object):
             log_probs = candidate_log_probs + tf.expand_dims(alive_log_probs, axis=2)
 
             # Add length penalty
-            length_penalty = tf.pow(((5. + (tf.cast(i, tf.float32) + 1.0)) / 6.), alpha)
+            length_penalty = tf.pow(((5.0 + (tf.cast(i, tf.float32) + 1.0)) / 6.0), alpha)
             log_probs = log_probs / length_penalty
             # Each batch item has beam_size * vocab_size candidate sequences. For each
             # batch item, get the k candidates with the highest log probabilities.
@@ -385,7 +399,9 @@ class TextDecoderSeq2Seq(object):
                 topk_log_probs = next_scores
                 topk_indices = next_tokens
             else:
-                topk_log_probs, topk_indices = tf.nn.top_k(flat_log_probs, k=beams_to_keep) # (batch_size x k (beams_to_keep))
+                topk_log_probs, topk_indices = tf.nn.top_k(
+                    flat_log_probs, k=beams_to_keep
+                )  # (batch_size x k (beams_to_keep))
 
             topk_beam_indices = topk_indices // vocab_size
             topk_seq, coordinates = _gather_beams(alive_seq, topk_beam_indices, batch_size, beams_to_keep)
@@ -496,7 +512,9 @@ class TextDecoderSeq2Seq(object):
         tokenized_input_dict_ragged["encoder_hidden_states"] = encoder_hidden_states
 
         if self.decoder_input_type_ids > -1:
-            tokenized_input_dict_ragged["decoder_input_type_ids"] = tf.ones_like(tokenized_input_dict_ragged["decoder_input_ids"]) * self.decoder_input_type_ids
+            tokenized_input_dict_ragged["decoder_input_type_ids"] = (
+                tf.ones_like(tokenized_input_dict_ragged["decoder_input_ids"]) * self.decoder_input_type_ids
+            )
 
         all_predictions = []
         matched_positions = tf.constant([-1] * batch_size_updated)
@@ -510,15 +528,13 @@ class TextDecoderSeq2Seq(object):
             all_cache_value = result["decoder_all_cache_value"]
             encoder_hidden_states = result["encoder_hidden_states"]
 
-            model_logits = model_logits/temperature
+            model_logits = model_logits / temperature
 
             if top_k > 0:
                 model_logits = top_k_logits(model_logits, k=top_k)
             if top_p > 0:
                 model_logits = top_p_logits(model_logits, p=top_p)
 
-
-
             if do_sample:
                 prediction_ids = tf.random.categorical(model_logits, num_samples=1)
                 input_ids = tf.cast(prediction_ids, tf.int32)
@@ -573,8 +589,8 @@ class TextDecoderSeq2Seq(object):
         tokenized_input_dict,
         max_iterations,
         beam_size=3,
-        sampling_temperature = 1.0,
-        alpha = 0.0,
+        sampling_temperature=1.0,
+        alpha=0.0,
         num_return_sequences=1,
         eos_id=-100,
         top_k=0,
@@ -583,7 +599,13 @@ class TextDecoderSeq2Seq(object):
         mode="greedy",
     ):
         if mode == "greedy":
-            result = self.greedy_decode(tokenized_input_dict, max_iterations=max_iterations, temperature=sampling_temperature, do_sample=do_sample, eos_id=eos_id)
+            result = self.greedy_decode(
+                tokenized_input_dict,
+                max_iterations=max_iterations,
+                temperature=sampling_temperature,
+                do_sample=do_sample,
+                eos_id=eos_id,
+            )
         if mode == "beam":
             result = self.beam_decode(
                 tokenized_input_dict,
